@@ -106,9 +106,21 @@ class TestGetLicenses(CommandLineTestCase):
         output_string = create_output_string(args)
         self.assertNotIn('<table>', output_string)
 
+    def test_from_meta(self):
+        from_args = ['--from=meta']
+        args = self.parser.parse_args(from_args)
+        table = create_licenses_table(args)
+
+        output_fields = get_output_fields(args)
+        self.assertIn('License', output_fields)
+
+        license_columns = self._create_license_columns(table)
+        license_notation_as_meta = 'BSD-3-Clause'
+        self.assertIn(license_notation_as_meta, license_columns)
+
     def test_from_classifier(self):
-        from_classifier_args = ['--from=classifier']
-        args = self.parser.parse_args(from_classifier_args)
+        from_args = ['--from=classifier']
+        args = self.parser.parse_args(from_args)
         table = create_licenses_table(args)
 
         output_fields = get_output_fields(args)
@@ -119,8 +131,8 @@ class TestGetLicenses(CommandLineTestCase):
         self.assertIn(license_notation_as_classifier, license_columns)
 
     def test_from_mixed(self):
-        from_classifier_args = ['--from=mixed']
-        args = self.parser.parse_args(from_classifier_args)
+        from_args = ['--from=mixed']
+        args = self.parser.parse_args(from_args)
         table = create_licenses_table(args)
 
         output_fields = get_output_fields(args)
@@ -346,11 +358,11 @@ class TestGetLicenses(CommandLineTestCase):
         self.assertEqual(RULE_FRAME, table.hrules)
 
     def test_format_plain_vertical(self):
-        format_plain_args = ['--format=plain-vertical']
+        format_plain_args = ['--format=plain-vertical', '--from=classifier']
         args = self.parser.parse_args(format_plain_args)
         output_string = create_output_string(args)
         self.assertIsNotNone(
-            re.search(r'pytest\n\d\.\d\.\d\nMIT license\n', output_string))
+            re.search(r'pytest\n\d\.\d\.\d\nMIT License\n', output_string))
 
     def test_format_markdown(self):
         format_markdown_args = ['--format=markdown']
@@ -567,3 +579,47 @@ def test_output_file_none(monkeypatch):
     # stdout and stderr are expected not to be called
     assert '' == mocked_stdout.printed
     assert '' == mocked_stderr.printed
+
+
+def test_allow_only(monkeypatch):
+    licenses = (
+        "BSD License",
+        "Apache Software License",
+        "Mozilla Public License 2.0 (MPL 2.0)",
+        "MIT License, Mozilla Public License 2.0 (MPL 2.0)",
+        "Apache Software License, BSD License",
+        "Python Software Foundation License, MIT License",
+        "Public Domain, Python Software Foundation License, BSD License,"
+        "GNU General Public License (GPL)",
+        "GNU Library or Lesser General Public License (LGPL)",
+    )
+    allow_only_args = ['--allow-only={}'.format(";".join(licenses))]
+    mocked_stdout = MockStdStream()
+    mocked_stderr = MockStdStream()
+    monkeypatch.setattr(sys.stdout, 'write', mocked_stdout.write)
+    monkeypatch.setattr(sys.stderr, 'write', mocked_stderr.write)
+    monkeypatch.setattr(sys, 'exit', lambda n: None)
+    args = create_parser().parse_args(allow_only_args)
+    create_licenses_table(args)
+
+    assert '' == mocked_stdout.printed
+    assert 'license MIT License not in allow-only licenses was found for ' \
+           'package' in mocked_stderr.printed
+
+
+def test_fail_on(monkeypatch):
+    licenses = (
+        "MIT License",
+    )
+    allow_only_args = ['--fail-on={}'.format(";".join(licenses))]
+    mocked_stdout = MockStdStream()
+    mocked_stderr = MockStdStream()
+    monkeypatch.setattr(sys.stdout, 'write', mocked_stdout.write)
+    monkeypatch.setattr(sys.stderr, 'write', mocked_stderr.write)
+    monkeypatch.setattr(sys, 'exit', lambda n: None)
+    args = create_parser().parse_args(allow_only_args)
+    create_licenses_table(args)
+
+    assert '' == mocked_stdout.printed
+    assert 'fail-on license MIT License was found for ' \
+           'package' in mocked_stderr.printed
